==> zhongyan-manage-service-api-3.0.40-sources.jar: cn/com/duiba/cloud/manage/service/api/model/constant/dept/export/ExportTemplatePathConstant.java <==
package cn.com.duiba.cloud.manage.service.api.model.constant.dept.export;

/**
 * @author linzhou
 * @ClassName ExportTemplatePathConstant.java
 * @createTime 2021年12月02日 14:00:00
 * @Description 导出导入模板常量类
 */
public class ExportTemplatePathConstant {
    public static final String EXPORT_STAFF_INVITE_TEMPLATE_PATH = "export/员工管理失败导出模版.xlsx";

    public static final String EXPORT_ROLE_STAFF_TEMPLATE_PATH = "export/角色员工失败导出模版.xlsx";

    public static final String EXPORT_DEPT_STAFF_TEMPLATE_PATH = "export/部门员工导出模板.xlsx";

    public static final String EXPORT_STATISTICS_PAGE_TEMPLATE_PATH = "export/页面数据明细导出模板.xlsx";

    public static final String EXPORT_STATISTICS_UNIT_TEMPLATE_PATH = "export/组件数据明细导出模板.xlsx";

    public static final String EXPORT_SUPPLIER_GOODS_TEMPLATE_PATH = "export/供应商商品导出模板.xlsx";

    public static final String EXPORT_TAG_USER_TEMPLATE_PATH = "export/标签值用户关联失败导出模版.xlsx";

    public static final String EXPORT_WECHAT_DATA_DETAIL_TEMPLATE_PATH = "export/微信二维码数据明细导出模板.xlsx";

    public static final String EXPORT_CHEAT_LIST_TEMPLATE_PATH = "export/黑灰名单导入失败导出模版.xlsx";

    public static final String EXPORT_TERMINAL_STAFF_TEMPLATE_PATH = "export/终端业务员失败导出模版.xlsx";

    public static final String EXPORT_ACQUIRE_CUSTOMER_DATA = "export/获取活动数据导出模板.xlsx";


    public static final String EXPORT_ACTIVITY_DATA_TEMPLATE_PATH = "export/活动数据导入失败导出模版.xlsx";


    public static final String EXPORT_PEACE_REMAIN_TEMPLATE_PATH = "export/平和星余额报表模板.xlsx";

    public static final String EXPORT_ACTIVITY_JOIN_TEMPLATE_PATH = "export/心中的远方参与模板.xlsx";

    public static final String EXPORT_ACTIVITY_TASK_TEMPLATE_PATH = "export/心中的远方任务模板.xlsx";

    public static final String EXPORT_ACTIVITY_PRIZE_TEMPLATE_PATH = "export/心中的远方奖品模板.xlsx";
    public static final String EXPORT_USER_VIEW_TEMPLATE_PATH = "export/时段独立访客数报表模板.xlsx";

    public static final String EXPORT_USER_ADDRESS_TEMPLATE_PATH = "export/用户地区报表模版.xlsx";

    public static final String EXPORT_ZERO_USER_SALE_TEMPLATE_PATH = "export/零售户资产管理报表模版.xlsx";

    public static final String EXPORT_CUSTOMER_ASSET_MANAGEMENT_TEMPLATE_PATH = "export/客户资产管理报表模版.xlsx";

    public static final String EXPORT_TRAVEL_POINT_REMAIN_TEMPLATE_PATH = "export/旅行选择积分余额报表模板.xlsx";

    public static final String EXPORT_TRAVEL_RETENTION_TEMPLATE_PATH = "export/旅行选择留存率报表模板.xlsx";

    // 云健身复用
    public static final String EXPORT_TRAVEL_ACTIVITY_TASK_TEMPLATE_PATH = "export/旅行的选择任务模板.xlsx";

    public static final String EXPORT_HEART_SIGN_ACTIVITY_TASK_TEMPLATE_PATH = "export/夏日限定一路向上任务模版.xlsx";

    public static final String EXPORT_TRAVEL_ACTIVITY_JOIN_TEMPLATE_PATH  = "export/旅行的选择参与模板.xlsx";

    public static final String EXPORT_TRAVEL_ACTIVITY_PRIZE_TEMPLATE_PATH = "export/旅行的选择奖品模板.xlsx";







    public static final String EXPORT_DISPLAY_DETAIL_TEMPLATE_PATH = "export/陈列竞赛活动明细报表模板.xlsx";

    public static final String EXPORT_DISPLAY_POINT_TEMPLATE_PATH = "export/陈列竞赛活动积分记录报表模板.xlsx";
    public static final String EXPORT_VOTE_DETAIL_TEMPLATE_PATH = "export/参与明细投票活动导出模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_TEMPLATE_PATH = "export/年度计划模版.xlsx";

    public static final String EXPORT_QUARTER_PLAN_TEMPLATE_PATH = "export/季度计划模版.xlsx";

    public static final String EXPORT_MONTH_PLAN_TEMPLATE_PATH = "export/月度计划模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_REVIEW_TEMPLATE_PATH = "export/年度计划总览模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_FAIL_TEMPLATE_PATH = "export/运营计划导出失败模板.xlsx";


    public static final String EXPORT_PLAN_DATA_REFLOW = "export/运营计划活动数据回流模板.xlsx";

    public static final String TWEETS_PLAN_EXPORT="export/推文月度计划导出模板.xlsx";

    public static final String EXPORT_APPROVAL_SHEET = "export/审批单导出模版.xlsx";

    public static final String EXPORT_CHEAT_LOG_TEMPLATE_PATH = "export/撞库明细导出模版.xlsx";
    public static final String EXPORT_BLACK_WHITE_TEMPLATE_PATH = "export/名单管理导出模版.xlsx";

    public static final String IMPORT_AREA_TEMPLATE_PATH = "import/导入市场.xlsx";



    public static final String EXPORT_TWEET_PLAN_TEMPLATE_PATH = "export/推文计划失败导出模版.xlsx";


    public static final String EXPORT_OPERATIONAL_PLAN_TEMPLATE_PATH = "export/营销活动计划失败导出模板.xlsx";

    public static final String EXPORT_ZGD_RISK_TEMPLATE_PATH = "export/风控记录导出模版.xlsx";
}

==> zhongyan-manage-service-api-3.0.45-sources.jar: cn/com/duiba/cloud/manage/service/api/model/constant/dept/export/ExportTemplatePathConstant.java <==
package cn.com.duiba.cloud.manage.service.api.model.constant.dept.export;

/**
 * @author linzhou
 * @ClassName ExportTemplatePathConstant.java
 * @createTime 2021年12月02日 14:00:00
 * @Description 导出导入模板常量类
 */
public class ExportTemplatePathConstant {
    public static final String EXPORT_STAFF_INVITE_TEMPLATE_PATH = "export/员工管理失败导出模版.xlsx";

    public static final String EXPORT_ROLE_STAFF_TEMPLATE_PATH = "export/角色员工失败导出模版.xlsx";

    public static final String EXPORT_DEPT_STAFF_TEMPLATE_PATH = "export/部门员工导出模板.xlsx";

    public static final String EXPORT_STATISTICS_PAGE_TEMPLATE_PATH = "export/页面数据明细导出模板.xlsx";

    public static final String EXPORT_STATISTICS_UNIT_TEMPLATE_PATH = "export/组件数据明细导出模板.xlsx";

    public static final String EXPORT_SUPPLIER_GOODS_TEMPLATE_PATH = "export/供应商商品导出模板.xlsx";

    public static final String EXPORT_TAG_USER_TEMPLATE_PATH = "export/标签值用户关联失败导出模版.xlsx";

    public static final String EXPORT_WECHAT_DATA_DETAIL_TEMPLATE_PATH = "export/微信二维码数据明细导出模板.xlsx";

    public static final String EXPORT_CHEAT_LIST_TEMPLATE_PATH = "export/黑灰名单导入失败导出模版.xlsx";

    public static final String EXPORT_TERMINAL_STAFF_TEMPLATE_PATH = "export/终端业务员失败导出模版.xlsx";

    public static final String EXPORT_ACQUIRE_CUSTOMER_DATA = "export/获取活动数据导出模板.xlsx";


    public static final String EXPORT_ACTIVITY_DATA_TEMPLATE_PATH = "export/活动数据导入失败导出模版.xlsx";


    public static final String EXPORT_PEACE_REMAIN_TEMPLATE_PATH = "export/平和星余额报表模板.xlsx";

    public static final String EXPORT_ACTIVITY_JOIN_TEMPLATE_PATH = "export/心中的远方参与模板.xlsx";

    public static final String EXPORT_ACTIVITY_TASK_TEMPLATE_PATH = "export/心中的远方任务模板.xlsx";

    public static final String EXPORT_ACTIVITY_PRIZE_TEMPLATE_PATH = "export/心中的远方奖品模板.xlsx";
    public static final String EXPORT_USER_VIEW_TEMPLATE_PATH = "export/时段独立访客数报表模板.xlsx";

    public static final String EXPORT_USER_ADDRESS_TEMPLATE_PATH = "export/用户地区报表模版.xlsx";

    public static final String EXPORT_ZERO_USER_SALE_TEMPLATE_PATH = "export/零售户资产管理报表模版.xlsx";

    public static final String EXPORT_CUSTOMER_ASSET_MANAGEMENT_TEMPLATE_PATH = "export/客户资产管理报表模版.xlsx";

    public static final String EXPORT_TRAVEL_POINT_REMAIN_TEMPLATE_PATH = "export/旅行选择积分余额报表模板.xlsx";

    public static final String EXPORT_TRAVEL_RETENTION_TEMPLATE_PATH = "export/旅行选择留存率报表模板.xlsx";

    // 云健身复用
    public static final String EXPORT_TRAVEL_ACTIVITY_TASK_TEMPLATE_PATH = "export/旅行的选择任务模板.xlsx";

    public static final String EXPORT_HEART_SIGN_ACTIVITY_TASK_TEMPLATE_PATH = "export/向往的冬日运动任务模版.xlsx";

    public static final String EXPORT_TRAVEL_ACTIVITY_JOIN_TEMPLATE_PATH  = "export/旅行的选择参与模板.xlsx";

    public static final String EXPORT_TRAVEL_ACTIVITY_PRIZE_TEMPLATE_PATH = "export/旅行的选择奖品模板.xlsx";







    public static final String EXPORT_DISPLAY_DETAIL_TEMPLATE_PATH = "export/陈列竞赛活动明细报表模板.xlsx";

    public static final String EXPORT_DISPLAY_POINT_TEMPLATE_PATH = "export/陈列竞赛活动积分记录报表模板.xlsx";
    public static final String EXPORT_VOTE_DETAIL_TEMPLATE_PATH = "export/参与明细投票活动导出模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_TEMPLATE_PATH = "export/年度计划模版.xlsx";

    public static final String EXPORT_QUARTER_PLAN_TEMPLATE_PATH = "export/季度计划模版.xlsx";

    public static final String EXPORT_MONTH_PLAN_TEMPLATE_PATH = "export/月度计划模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_REVIEW_TEMPLATE_PATH = "export/年度计划总览模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_FAIL_TEMPLATE_PATH = "export/运营计划导出失败模板.xlsx";


    public static final String EXPORT_PLAN_DATA_REFLOW = "export/运营计划活动数据回流模板.xlsx";

    public static final String TWEETS_PLAN_EXPORT="export/推文月度计划导出模板.xlsx";

    public static final String EXPORT_APPROVAL_SHEET = "export/审批单导出模版.xlsx";

    public static final String EXPORT_CHEAT_LOG_TEMPLATE_PATH = "export/撞库明细导出模版.xlsx";
    public static final String EXPORT_BLACK_WHITE_TEMPLATE_PATH = "export/名单管理导出模版.xlsx";

    public static final String IMPORT_AREA_TEMPLATE_PATH = "import/导入市场.xlsx";



    public static final String EXPORT_TWEET_PLAN_TEMPLATE_PATH = "export/推文计划失败导出模版.xlsx";


    public static final String EXPORT_OPERATIONAL_PLAN_TEMPLATE_PATH = "export/营销活动计划失败导出模板.xlsx";

    public static final String EXPORT_ZGD_RISK_TEMPLATE_PATH = "export/风控记录导出模版.xlsx";

    public static final String EXPORT_SALE_CHECK_TEMPLATE_PATH = "export/入网审核模版.xlsx";
    public static final String EXPORT_SALE_APPEAL_TEMPLATE_PATH = "export/入网申诉模版.xlsx";
}
